#ifndef FIRST_MENU_UNI_H
#define FIRST_MENU_UNI_H

/*!
  \file
  \brief j[ Unicode \[X`

  \author Satofumi KAMIMURA

  $Id$
*/

#include <SDL.h>

const static Uint16 FirstMenu_title[] = { 0x767e, 0x4eba, 0x4e00, 0x9996, 0x30bf, 0x30a4, 0x30d4, 0x30f3, 0x30b0, 0x0 }; // Sl^CsO
const static Uint16 FirstMenu_practice[] = { 0x30bf, 0x30a4, 0x30d4, 0x30f3, 0x30b0, 0x7df4, 0x7fd2, 0x0 }; // ^CsOK
const static Uint16 FirstMenu_network[] = { 0x30cd, 0x30c3, 0x30c8, 0x30ef, 0x30fc, 0x30af, 0x5bfe, 0x6226, 0x0 }; // lbg[Nΐ
const static Uint16 FirstMenu_history[] = { 0x5c65, 0x6b74, 0x306e, 0x95b2, 0x89a7, '(', 0x307e, 0x3060, ')', 0x0 }; // ̉{(܂)
const static Uint16 FirstMenu_option[] = { 0x30aa, 0x30d7, 0x30b7, 0x30e7, 0x30f3, 0x0 }; // IvV
const static Uint16 FirstMenu_quit[] = { 0x30b2, 0x30fc, 0x30e0, 0x306e, 0x7d42, 0x4e86, 0x0 }; // Q[̏I

#endif /* ! FIRST_MENU_UNI_H */
